@@ -597,6 +597,55 @@ parseOverdriveVoltOffset(std::vector<std::string> const &ppOdClkVoltageLines)
   return {};
 }
 
+std::optional<std::pair<units::voltage::millivolt_t, units::voltage::millivolt_t>>
+parseOverdriveVoltOffsetRangeLine(std::string const &line)
+{
+  // Relevant lines format (kernel 6.14+):
+  // ...
+  // label:     -200mv          0mv
+  // ...
+  std::regex const regex(R"(^(?:[^\:\s]+)\s*:\s*(-?\d+)\s*mV\s*(\d+)\s*mV\s*$)",
+                         std::regex::icase);
+  std::smatch result;
+
+  if (std::regex_search(line, result, regex)) {
+    int min{0}, max{0};
+    if (Utils::String::toNumber<int>(min, result[1]) &&
+        Utils::String::toNumber<int>(max, result[2]))
+      return std::make_pair(units::make_unit<units::voltage::millivolt_t>(min),
+                            units::make_unit<units::voltage::millivolt_t>(max));
+  }
+
+  return {};
+}
+
+std::optional<std::pair<units::voltage::millivolt_t, units::voltage::millivolt_t>>
+parseOverdriveVoltOffsetRange(std::vector<std::string> const &ppOdClkVoltageLines)
+{
+  // Relevant lines format (kernel 6.14+):
+  // ...
+  // OD_RANGE:
+  // ...
+  // VDDGFX_OFFSET:     -200mv          0mv
+  // ...
+  auto rangeIt = std::find_if(
+      ppOdClkVoltageLines.cbegin(), ppOdClkVoltageLines.cend(),
+      [&](std::string const &line) {
+        return line.find("OD_RANGE:") != std::string::npos;
+      });
+  if (rangeIt != ppOdClkVoltageLines.cend()) {
+    auto targetIt = std::find_if(
+        rangeIt, ppOdClkVoltageLines.cend(), [&](std::string const &line) {
+          return line.find("VDDGFX_OFFSET:") != std::string::npos;
+        });
+
+    if (targetIt != ppOdClkVoltageLines.cend())
+      return parseOverdriveVoltOffsetRangeLine(*targetIt);
+  }
+
+  return {};
+}
+
 std::optional<std::vector<std::string>>
 parseOverdriveClkControls(std::vector<std::string> const &ppOdClkVoltageLines)
 {
@@ -629,6 +678,128 @@ getOverdriveClkControlCmdId(std::string_view controlName)
   return {};
 }
 
+std::optional<std::string>
+getOverdriveClkOffsetControlCmdId(std::string_view controlName)
+{
+  // NOTE: Clock offsets implementation uses the same command ids of clock
+  // control commands. This deviates from the voltage offset command, which is
+  // terminated by the 'o' character.
+  return getOverdriveClkControlCmdId(controlName);
+}
+
+std::optional<std::vector<std::string>> parseOverdriveClkOffsetControls(
+    std::vector<std::string> const &ppOdClkVoltageLines)
+{
+  std::regex const regex(R"(^OD_(\wCLK)_OFFSET:\s*$)", std::regex::icase);
+  std::vector<std::string> controlNames;
+
+  for (auto const &line : ppOdClkVoltageLines) {
+    std::smatch result;
+    if (!std::regex_search(line, result, regex))
+      continue;
+
+    controlNames.emplace_back(result[1]);
+  }
+
+  if (!controlNames.empty())
+    return controlNames;
+
+  return {};
+}
+
+std::optional<units::frequency::megahertz_t>
+parseOverdriveClkOffsetLine(std::string const &line)
+{
+  // Relevant lines format (kernel 6.14+):
+  // OD_SCLK_OFFSET:
+  // -200MHz
+  // ...
+  std::regex const regex(R"(^(-?\d+)\s*Mhz\s*$)", std::regex::icase);
+
+  std::smatch result;
+  if (std::regex_search(line, result, regex)) {
+    int value;
+    if (Utils::String::toNumber(value, result[1]))
+      return units::frequency::megahertz_t(value);
+  }
+
+  return {};
+}
+
+std::optional<units::frequency::megahertz_t>
+parseOverdriveClkOffset(std::string_view controlName,
+                        std::vector<std::string> const &ppOdClkVoltageLines)
+{
+  // Relevant lines format (kernel 6.14+):
+  // ...
+  // OD_controlName_OFFSET:
+  // -100Mhz
+  // OD_otherLbl:
+  // ...
+  auto targetIt = std::find_if(
+      ppOdClkVoltageLines.cbegin(), ppOdClkVoltageLines.cend(),
+      [&](std::string const &line) {
+        return line.find("OD_" + std::string(controlName) + "_OFFSET:") !=
+               std::string::npos;
+      });
+  if (targetIt != ppOdClkVoltageLines.cend() &&
+      std::next(targetIt) != ppOdClkVoltageLines.cend())
+    return parseOverdriveClkOffsetLine(*std::next(targetIt));
+
+  return {};
+}
+
+std::optional<std::pair<units::frequency::megahertz_t, units::frequency::megahertz_t>>
+parseOverdriveClkRangeLine(std::string const &line)
+{
+  // Relevant lines format (kernel 6.14+):
+  // ...
+  // label:     -500Mhz       1000Mhz
+  // ...
+  std::regex const regex(R"(^(?:[^\:\s]+)\s*:\s*(-?\d+)\s*Mhz\s*(\d+)\s*Mhz\s*$)",
+                         std::regex::icase);
+  std::smatch result;
+
+  if (std::regex_search(line, result, regex)) {
+    int min{0}, max{0};
+    if (Utils::String::toNumber<int>(min, result[1]) &&
+        Utils::String::toNumber<int>(max, result[2]))
+      return std::make_pair(units::make_unit<units::frequency::megahertz_t>(min),
+                            units::make_unit<units::frequency::megahertz_t>(max));
+  }
+
+  return {};
+}
+
+std::optional<std::pair<units::frequency::megahertz_t, units::frequency::megahertz_t>>
+parseOverdriveClkOffsetRange(std::string_view controlName,
+                             std::vector<std::string> const &ppOdClkVoltageLines)
+{
+  // Relevant lines format (kernel 6.14+):
+  // ...
+  // OD_RANGE:
+  // ...
+  // controlName_OFFSET:     -500Mhz       1000Mhz
+  // ...
+  auto rangeIt = std::find_if(
+      ppOdClkVoltageLines.cbegin(), ppOdClkVoltageLines.cend(),
+      [&](std::string const &line) {
+        return line.find("OD_RANGE:") != std::string::npos;
+      });
+  if (rangeIt != ppOdClkVoltageLines.cend()) {
+    auto targetIt = std::find_if(
+        rangeIt, ppOdClkVoltageLines.cend(), [&](std::string const &line) {
+          return line.find(std::string(controlName) + "_OFFSET:") !=
+                 std::string::npos;
+        });
+
+    if (targetIt != ppOdClkVoltageLines.cend())
+      return parseOverdriveClkRangeLine(*targetIt);
+  }
+
+  return {};
+}
+
 std::optional<std::vector<unsigned int>> ppOdClkVoltageFreqRangeOutOfRangeStates(
     std::string const &controlName,
     std::vector<std::string> const &ppOdClkVoltageLines)
@@ -874,6 +1045,95 @@ parseOverdriveFanCurveSpeedRange(std::vector<std::string> const &fanCurveLines)
   return {};
 }
 
+std::optional<bool>
+parseOverdriveFanStop(std::vector<std::string> const &fanStopLines)
+{
+  // Relevant lines format (kernel 6.13+):
+  // FAN_ZERO_RPM_ENABLE:
+  // 1
+  // OD_RANGE:
+  // ZERO_RPM_ENABLE: 0 1
+
+  auto targetIt = std::find_if(
+      fanStopLines.cbegin(), fanStopLines.cend(), [&](std::string const &line) {
+        return line.find("FAN_ZERO_RPM_ENABLE:") != std::string::npos;
+      });
+  if (targetIt != fanStopLines.cend() &&
+      std::next(targetIt) != fanStopLines.cend()) {
+    std::regex const regex(R"(^\s*(\d+)\s*$)", std::regex::icase);
+
+    std::smatch result;
+    if (std::regex_search(*std::next(targetIt), result, regex)) {
+      int value;
+      if (Utils::String::toNumber(value, result[1]))
+        return value > 0;
+    }
+  }
+
+  return {};
+}
+
+std::optional<units::temperature::celsius_t>
+parseOverdriveFanStopTemp(std::vector<std::string> const &fanStopTempLines)
+{
+  // Relevant lines format (kernel 6.13+):
+  // FAN_ZERO_RPM_STOP_TEMPERATURE:
+  // 20
+  // OD_RANGE:
+  // ZERO_RPM_STOP_TEMPERATURE: 10 100
+
+  auto targetIt = std::find_if(
+      fanStopTempLines.cbegin(), fanStopTempLines.cend(),
+      [&](std::string const &line) {
+        return line.find("FAN_ZERO_RPM_STOP_TEMPERATURE:") != std::string::npos;
+      });
+  if (targetIt != fanStopTempLines.cend() &&
+      std::next(targetIt) != fanStopTempLines.cend()) {
+    std::regex const regex(R"(^\s*(-?\d+)\s*$)", std::regex::icase);
+
+    std::smatch result;
+    if (std::regex_search(*std::next(targetIt), result, regex)) {
+      int value;
+      if (Utils::String::toNumber(value, result[1]))
+        return units::temperature::celsius_t(value);
+    }
+  }
+
+  return {};
+}
+
+std::optional<std::pair<units::temperature::celsius_t, units::temperature::celsius_t>>
+parseOverdriveFanStopTempRange(std::vector<std::string> const &fanStopTempLines)
+{
+  // Relevant lines format (kernel 6.13+):
+  // FAN_ZERO_RPM_STOP_TEMPERATURE:
+  // 20
+  // OD_RANGE:
+  // ZERO_RPM_STOP_TEMPERATURE: 10 100
+
+  auto targetIt = std::find_if(
+      fanStopTempLines.cbegin(), fanStopTempLines.cend(),
+      [&](std::string const &line) {
+        return line.find("OD_RANGE:") != std::string::npos;
+      });
+  if (targetIt != fanStopTempLines.cend() &&
+      std::next(targetIt) != fanStopTempLines.cend()) {
+    std::regex const regex(R"(^ZERO_RPM_STOP_TEMPERATURE\s*:\s*(\d+)\s*(\d+)$)",
+                           std::regex::icase);
+    std::smatch result;
+    if (std::regex_search(*std::next(targetIt), result, regex)) {
+      int min{0}, max{0};
+      if (Utils::String::toNumber<int>(min, result[1]) &&
+          Utils::String::toNumber<int>(max, result[2]))
+        return std::make_pair(
+            units::make_unit<units::temperature::celsius_t>(min),
+            units::make_unit<units::temperature::celsius_t>(max));
+    }
+  }
+
+  return {};
+}
+
 bool isPowerProfileModeDataColumnar(std::vector<std::string> const &data)
 {
   if (data.empty())
@@ -926,6 +1186,24 @@ bool hasOverdriveClkControl(std::vector<std::string> const &data)
   return false;
 }
 
+bool hasOverdriveClkOffsetControl(std::vector<std::string> const &data)
+{
+  std::regex const clkRegex(R"(^OD_\wCLK_OFFSET:)", std::regex::icase);
+  std::smatch result;
+
+  auto clkIt = std::find_if(data.cbegin(), data.cend(),
+                            [&](std::string const &line) {
+                              return std::regex_match(line, result, clkRegex);
+                            });
+
+  if (clkIt != data.cend() && std::next(clkIt) != data.cend()) {
+    auto state = parseOverdriveClkOffsetLine(*std::next(clkIt));
+    return state.has_value();
+  }
+
+  return false;
+}
+
 bool hasOverdriveVoltCurveControl(std::vector<std::string> const &data)
 {
   auto curveIt = std::find_if(
@@ -991,14 +1269,4 @@ bool hasOverdriveFanAcousticLimitControl(std::vector<std::string> const &data)
   return offsetIt != data.cend();
 }
 
-bool hasOverdriveFanCurveControl(std::vector<std::string> const &data)
-{
-  auto offsetIt = std::find_if(
-      data.cbegin(), data.cend(), [&](std::string const &line) {
-        return line.find("OD_FAN_CURVE:") != std::string::npos;
-      });
-
-  return offsetIt != data.cend();
-}
-
 } // namespace Utils::AMD
