@@ -22,6 +22,7 @@ AMD::PMFixedProvider::provideGPUControls(IGPUInfo const &gpuInfo,
   if (gpuInfo.vendor() != Vendor::AMD)
     return {};
 
+  auto driver = gpuInfo.info(IGPUInfo::Keys::driver);
   if (gpuInfo.hasCapability(GPUInfoPM::Legacy)) {
 
     auto powerMethod = gpuInfo.path().sys / "power_method";
@@ -34,8 +35,7 @@ AMD::PMFixedProvider::provideGPUControls(IGPUInfo const &gpuInfo,
         std::make_unique<SysFSDataSource<std::string>>(powerMethod),
         std::make_unique<SysFSDataSource<std::string>>(powerProfile)));
   }
-  else if (gpuInfo.hasCapability(GPUInfoPM::Radeon) ||
-           gpuInfo.hasCapability(GPUInfoPM::Amdgpu)) {
+  else if (gpuInfo.hasCapability(GPUInfoPM::Radeon) || driver == "amdgpu") {
 
     auto perfLevel = gpuInfo.path().sys / "power_dpm_force_performance_level";
     if (!Utils::File::isSysFSEntryValid(perfLevel))
