@@ -3,15 +3,13 @@
 
 #pragma once
 
+#include "core/idatasource.h"
 #include "pmfixed.h"
 #include <memory>
 #include <string>
 #include <string_view>
 #include <vector>
 
-template<typename...>
-class IDataSource;
-
 namespace AMD {
 
 class PMFixedR600 : public AMD::PMFixed
