@@ -8,8 +8,7 @@
 #include "common/stringutils.h"
 #include <algorithm>
 #include <cctype>
-#include <easylogging++.h>
-#include <fmt/format.h>
+#include <spdlog/spdlog.h>
 #include <utility>
 
 class GPUInfoRevisionDataSource
@@ -30,8 +29,7 @@ class GPUInfoRevisionDataSource
       return true;
     }
 
-    LOG(WARNING) << fmt::format("Cannot retrieve device revision from {}",
-                                filePath.c_str());
+    SPDLOG_WARN("Cannot retrieve device revision from {}", filePath.c_str());
     return false;
   }
 };
