@@ -4,14 +4,12 @@
 #pragma once
 
 #include "../igpuinfo.h"
+#include "core/idatasource.h"
 #include <cstddef>
 #include <memory>
 #include <string>
 #include <string_view>
 
-template<typename...>
-class IDataSource;
-
 class GPUInfoVulkan final : public IGPUInfo::IProvider
 {
  public:
@@ -24,10 +22,11 @@ class GPUInfoVulkan final : public IGPUInfo::IProvider
 
   std::vector<std::pair<std::string, std::string>>
   provideInfo(Vendor vendor, int gpuIndex, IGPUInfo::Path const &path,
-              IHWIDTranslator const &hwIDTranslator) override;
+              IHWIDTranslator const &hwIDTranslator) const override;
 
   std::vector<std::string>
-  provideCapabilities(Vendor vendor, int, IGPUInfo::Path const &path) override;
+  provideCapabilities(Vendor vendor, int,
+                      IGPUInfo::Path const &path) const override;
 
  private:
   std::string parseApiVersion(std::string const &src, size_t pos) const;
