@@ -25,7 +25,8 @@ class Session final : public ISession
   Session(std::shared_ptr<IProfileApplicator> profileApplicator,
           std::unique_ptr<IProfileManager> &&profileManager,
           std::unique_ptr<IProfileViewFactory> &&profileViewFactory,
-          std::unique_ptr<IHelperMonitor> &&helperMonitor) noexcept;
+          std::unique_ptr<IHelperMonitor> &&helperMonitor,
+          bool logProfileStack = false) noexcept;
 
   void addManualProfileObserver(
       std::shared_ptr<ISession::ManualProfileObserver> observer) override;
@@ -34,8 +35,12 @@ class Session final : public ISession
 
   void init(ISysModel const &model) override;
   bool toggleManualProfile(std::string const &profileName) override;
+  bool activateManualProfile(std::string const &profileName) override;
+  bool deactivateManualProfile(std::string const &profileName) override;
   IProfileManager &profileManager() const override;
 
+  void logProfileStack(bool enable) override;
+
  private:
   void profileAdded(std::string const &profileName);
   void profileRemoved(std::string const &profileName);
@@ -55,15 +60,13 @@ class Session final : public ISession
       std::optional<std::reference_wrapper<IProfileView>> baseProfileView,
       std::vector<std::string> const &profileNames);
 
-  std::optional<std::reference_wrapper<IProfileView>>
-  getBaseView(std::deque<std::unique_ptr<IProfileView>> const &pViews,
-              std::optional<std::string> const &manualProfile) const;
-
   void queueProfileView(std::string const &profileName);
   void dequeueProfileView(std::string const &profileName);
 
   void notifyManualProfileToggled(std::string const &profileName, bool active);
 
+  void logProfileStack() const;
+
   std::shared_ptr<IProfileApplicator> profileApplicator_;
   std::unique_ptr<IProfileManager> profileManager_;
   std::unique_ptr<IProfileViewFactory> profileViewFactory_;
@@ -88,4 +91,6 @@ class Session final : public ISession
 
   std::vector<std::shared_ptr<ISession::ManualProfileObserver>> manualProfileObservers_;
   std::mutex manualProfileObserversMutex_;
+
+  bool logProfileStack_;
 };
