@@ -22,11 +22,10 @@
 #include "isysexplorer.h"
 #include "sysmodel.h"
 #include <algorithm>
-#include <easylogging++.h>
-#include <fmt/format.h>
 #include <iterator>
 #include <memory>
 #include <optional>
+#include <spdlog/spdlog.h>
 #include <string_view>
 #include <utility>
 
@@ -166,14 +165,14 @@ std::vector<std::unique_ptr<ICPUInfo>> SysModelFactory::parseCPUInfo() const
   for (auto const &line : cpuInfoLines) {
 
     if (line.empty()) { // push collected info
-      std::optional<int> socketId;
+      std::optional<int> physicalId;
       std::optional<int> coreId;
 
-      auto socketIdStr = Utils::CPU::parseProcCpuInfo(cpuInfoLines, *cpuId,
-                                                      "physical id");
-      if (socketIdStr.has_value() &&
-          Utils::String::toNumber<int>(value, *socketIdStr))
-        socketId = value;
+      auto physicalIdStr = Utils::CPU::parseProcCpuInfo(cpuInfoLines, *cpuId,
+                                                        "physical id");
+      if (physicalIdStr.has_value() &&
+          Utils::String::toNumber<int>(value, *physicalIdStr))
+        physicalId = value;
 
       auto coreIdStr = Utils::CPU::parseProcCpuInfo(cpuInfoLines, *cpuId,
                                                     "core id");
@@ -181,14 +180,15 @@ std::vector<std::unique_ptr<ICPUInfo>> SysModelFactory::parseCPUInfo() const
           Utils::String::toNumber<int>(value, *coreIdStr))
         coreId = value;
 
-      if (cpuId.has_value() && socketId.has_value() && coreId.has_value()) {
+      if (cpuId.has_value() && physicalId.has_value() && coreId.has_value()) {
         std::string cpuDir{"cpu"};
         cpuDir.append(std::to_string(*cpuId));
         auto executionUnitPath = basePath / cpuDir;
 
-        auto infoIt = std::find_if(
-            cpuInfo.cbegin(), cpuInfo.cend(),
-            [=](auto const &info) { return info->socketId() == *socketId; });
+        auto infoIt = std::find_if(cpuInfo.cbegin(), cpuInfo.cend(),
+                                   [=](auto const &info) {
+                                     return info->physicalId() == *physicalId;
+                                   });
         if (infoIt != cpuInfo.cend())
           static_cast<CPUInfo *>(infoIt->get())
               ->addExecutionUnit(
@@ -198,13 +198,13 @@ std::vector<std::unique_ptr<ICPUInfo>> SysModelFactory::parseCPUInfo() const
               ICPUInfo::ExecutionUnit(*cpuId, *coreId, executionUnitPath)};
 
           cpuInfo.emplace_back(
-              std::make_unique<CPUInfo>(*socketId, std::move(units)));
+              std::make_unique<CPUInfo>(*physicalId, std::move(units)));
         }
 
-        socketId = cpuId = coreId = std::nullopt;
+        physicalId = cpuId = coreId = std::nullopt;
       }
       else {
-        LOG(ERROR) << "Cannot parse some data from /proc/cpuinfo";
+        SPDLOG_DEBUG("Cannot parse some data from /proc/cpuinfo");
         return {};
       }
     }
@@ -231,8 +231,7 @@ int SysModelFactory::computeGPUIndex(std::string const &deviceRenderDName) const
   if (Utils::String::toNumber<int>(index, indexStr))
     index -= 128;
   else
-    LOG(ERROR) << fmt::format("Cannot compute GPU index for device {}.",
-                              deviceRenderDName.c_str());
+    SPDLOG_DEBUG("Cannot compute GPU index for device {}.", deviceRenderDName);
   return index;
 }
 
@@ -246,8 +245,7 @@ Vendor SysModelFactory::parseVendor(std::filesystem::path const &vendorPath) con
     if (Utils::String::toNumber<int>(dataValue, lines.front(), 16))
       vendor = Vendor{dataValue};
     else
-      LOG(ERROR) << fmt::format("Cannot parse vendor id from file {}.",
-                                vendorPath.c_str());
+      SPDLOG_DEBUG("Cannot parse vendor id from file {}.", vendorPath.c_str());
   }
 
   return vendor;
