@@ -13,6 +13,10 @@ SysModelSyncer::SysModelSyncer(std::unique_ptr<ISysModel> &&sysModel,
                                std::unique_ptr<IHelperSysCtl> &&helperSysCtl) noexcept
 : sysModel_(std::move(sysModel))
 , helperSysCtl_(std::move(helperSysCtl))
+, cmds_({"pp_od_clk_voltage", "fan_curve", "fan_zero_rpm_enable",
+         "fan_zero_rpm_stop_temperature", "fan_target_temperature",
+         "fan_minimum_pwm", "acoustic_target_rpm_threshold",
+         "acoustic_limit_rpm_threshold"})
 {
 }
 
@@ -43,6 +47,11 @@ void SysModelSyncer::settingChanged(QString const &key, QVariant const &value)
   }
 }
 
+void SysModelSyncer::logCommands(bool enable)
+{
+  helperSysCtl_->logCommands(enable);
+}
+
 void SysModelSyncer::init()
 {
   helperSysCtl_->init();
