@@ -19,6 +19,19 @@
         <translation>Hoch</translation>
     </message>
 </context>
+<context>
+    <name>AMD::PMFreqOffsetQMLItem</name>
+    <message>
+        <location filename="../core/components/controls/amd/pm/advanced/overdrive/freqoffset/pmfreqoffsetqmlitem.cpp" line="17"/>
+        <source>SCLK</source>
+        <translation>GPU</translation>
+    </message>
+    <message>
+        <location filename="../core/components/controls/amd/pm/advanced/overdrive/freqoffset/pmfreqoffsetqmlitem.cpp" line="18"/>
+        <source>MCLK</source>
+        <translation>Speicher</translation>
+    </message>
+</context>
 <context>
     <name>AMD::PMFreqRangeQMLItem</name>
     <message>
@@ -137,6 +150,11 @@
         <source>Speed</source>
         <translation>Geschwindigkeit</translation>
     </message>
+    <message>
+        <location filename="../qml/AMDOdFanCurveForm.qml" line="116"/>
+        <source>Fan stop</source>
+        <translation>Lüfterstopp</translation>
+    </message>
 </context>
 <context>
     <name>AMDPMFixedFreqForm</name>
@@ -435,6 +453,14 @@
         <translation>Spannung</translation>
     </message>
 </context>
+<context>
+    <name>FreqOffsetControl</name>
+    <message>
+        <location filename="../qml/FreqOffsetControl.qml" line="48"/>
+        <source>OFFSET</source>
+        <translation>OFFSET</translation>
+    </message>
+</context>
 <context>
     <name>FreqStateControl</name>
     <message>
