@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="en_US">
+<TS version="2.1" language="sv_SE">
 <context>
     <name>AMD::PMFixedQMLItem</name>
     <message>
@@ -19,6 +19,19 @@
         <translation>Hög</translation>
     </message>
 </context>
+<context>
+    <name>AMD::PMFreqOffsetQMLItem</name>
+    <message>
+        <location filename="../core/components/controls/amd/pm/advanced/overdrive/freqoffset/pmfreqoffsetqmlitem.cpp" line="17"/>
+        <source>SCLK</source>
+        <translation>GPU</translation>
+    </message>
+    <message>
+        <location filename="../core/components/controls/amd/pm/advanced/overdrive/freqoffset/pmfreqoffsetqmlitem.cpp" line="18"/>
+        <source>MCLK</source>
+        <translation>Minne</translation>
+    </message>
+</context>
 <context>
     <name>AMD::PMFreqRangeQMLItem</name>
     <message>
@@ -137,6 +150,11 @@
         <source>Speed</source>
         <translation>Hastighet</translation>
     </message>
+    <message>
+        <location filename="../qml/AMDOdFanCurveForm.qml" line="116"/>
+        <source>Fan stop</source>
+        <translation>Fläktstopp</translation>
+    </message>
 </context>
 <context>
     <name>AMDPMFixedFreqForm</name>
@@ -435,6 +453,14 @@
         <translation>Volt</translation>
     </message>
 </context>
+<context>
+    <name>FreqOffsetControl</name>
+    <message>
+        <location filename="../qml/FreqOffsetControl.qml" line="48"/>
+        <source>OFFSET</source>
+        <translation>FÖRSKJUTNING</translation>
+    </message>
+</context>
 <context>
     <name>FreqStateControl</name>
     <message>
