@@ -1,13 +1,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/components/controls/amd/pm/advanced/freqmode/pmfreqmode.h"
 
-namespace Tests {
-namespace AMD {
-namespace PMFreqMode {
+namespace Tests::AMD::PMFreqMode {
 
 TEST_CASE("AMD PMFreqMode tests", "[GPU][AMD][PM][PMAdvanced][PMFreqMode]")
 {
@@ -25,6 +23,5 @@ TEST_CASE("AMD PMFreqMode tests", "[GPU][AMD][PM][PMAdvanced][PMFreqMode]")
     REQUIRE(ts.active());
   }
 }
-} // namespace PMFreqMode
-} // namespace AMD
-} // namespace Tests
+
+} // namespace Tests::AMD::PMFreqMode
