@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2021 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 #include <catch2/trompeloeil.hpp>
 
 #include "common/commandqueuestub.h"
@@ -11,9 +11,7 @@
 
 extern template struct trompeloeil::reporter<trompeloeil::specialized>;
 
-namespace Tests {
-namespace AMD {
-namespace PMFreqRange {
+namespace Tests::AMD::PMFreqRange {
 
 class PMFreqRangeTestAdapter : public ::AMD::PMFreqRange
 {
@@ -359,6 +357,4 @@ TEST_CASE("AMD PMFreqRange tests",
   }
 }
 
-} // namespace PMFreqRange
-} // namespace AMD
-} // namespace Tests
+} // namespace Tests::AMD::PMFreqRange
