@@ -1,13 +1,11 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/components/controls/amd/pm/pmperfmode.h"
 
-namespace Tests {
-namespace AMD {
-namespace PMPerfMode {
+namespace Tests::AMD::PMPerfMode {
 
 TEST_CASE("AMD PMPerfMode tests", "[GPU][AMD][PM][PMPerfMode]")
 {
@@ -25,6 +23,5 @@ TEST_CASE("AMD PMPerfMode tests", "[GPU][AMD][PM][PMPerfMode]")
     REQUIRE(ts.active());
   }
 }
-} // namespace PMPerfMode
-} // namespace AMD
-} // namespace Tests
+
+} // namespace Tests::AMD::PMPerfMode
