@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 #include <catch2/trompeloeil.hpp>
 
 #include "common/commandqueuestub.h"
@@ -10,9 +10,7 @@
 
 extern template struct trompeloeil::reporter<trompeloeil::specialized>;
 
-namespace Tests {
-namespace AMD {
-namespace PMPowerCap {
+namespace Tests::AMD::PMPowerCap {
 
 class ULongDataSourceStub : public IDataSource<unsigned long>
 {
@@ -314,6 +312,5 @@ TEST_CASE("AMD PMPowerCap tests", "[GPU][AMD][PM][PMPowerCap]")
     REQUIRE(cmdValue == "80000000");
   }
 }
-} // namespace PMPowerCap
-} // namespace AMD
-} // namespace Tests
+
+} // namespace Tests::AMD::PMPowerCap
