@@ -281,12 +281,59 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
     }
 
     SECTION("Returns nothing for invalid input")
+    {
+      auto index = ::Utils::AMD::parsePowerProfileModeCurrentModeIndex({""});
+      REQUIRE_FALSE(index.has_value());
+    }
+  }
+
+  SECTION("parsePowerProfileModeModesColumnar")
+  {
+    SECTION("Returns power profile modes on asics with columnar data")
     {
       // clang-format off
-      std::vector<std::string> input{""};
+      std::vector<std::string> input{"    0 3D_FULL_SCREEN*  1  VIDEO 2 CUSTOM"};
       // clang-format on
 
-      auto index = ::Utils::AMD::parseDPMCurrentStateIndex(input);
+      auto modes = ::Utils::AMD::parsePowerProfileModeModesColumnar(input);
+      REQUIRE(modes.has_value());
+      REQUIRE(modes->size() == 2);
+
+      auto &[mode0, mode0Index] = modes->at(0);
+      REQUIRE(mode0 == "3D_FULL_SCREEN");
+      REQUIRE(mode0Index == 0);
+
+      auto &[mode1, mode1Index] = modes->at(1);
+      REQUIRE(mode1 == "VIDEO");
+      REQUIRE(mode1Index == 1);
+    }
+
+    SECTION("Returns nothing for invalid input")
+    {
+      auto index = ::Utils::AMD::parsePowerProfileModeModesColumnar({""});
+      REQUIRE_FALSE(index.has_value());
+    }
+  }
+
+  SECTION("parsePowerProfileModeCurrentModeIndex")
+  {
+    SECTION(
+        "Returns index of the active profile mode on asics with columnar data")
+    {
+      // clang-format off
+      std::vector<std::string> input{"    0 3D_FULL_SCREEN  1  VIDEO* 2 CUSTOM"};
+      // clang-format on
+
+      auto index =
+          ::Utils::AMD::parsePowerProfileModeCurrentModeIndexColumnar(input);
+      REQUIRE(index.has_value());
+      REQUIRE(*index == 1);
+    }
+
+    SECTION("Returns nothing for invalid input")
+    {
+      auto index =
+          ::Utils::AMD::parsePowerProfileModeCurrentModeIndexColumnar({""});
       REQUIRE_FALSE(index.has_value());
     }
   }
@@ -616,6 +663,33 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
     }
   }
 
+  SECTION("parseOverdriveVoltOffsetRange")
+  {
+    // clang-format off
+    std::vector<std::string> input{"OD_RANGE:",
+                                   "VDDGFX_OFFSET:     -200mV       0mV"};
+    // clang-format on
+
+    SECTION("Returns minimum and maximum voltage offset")
+    {
+      auto values = ::Utils::AMD::parseOverdriveVoltOffsetRange(input);
+      REQUIRE(values.has_value());
+      REQUIRE(values->first == units::voltage::millivolt_t(-200));
+      REQUIRE(values->second == units::voltage::millivolt_t(0));
+    }
+
+    SECTION("Returns nothing when there is no OD_RANGE in input")
+    {
+      // clang-format off
+      std::vector<std::string> input{"OTHER:",
+                                     "VDDGFX_OFFSET:     -200mV       0mV"};
+      // clang-format on
+
+      auto empty = ::Utils::AMD::parseOverdriveVoltOffsetRange(input);
+      REQUIRE_FALSE(empty.has_value());
+    }
+  }
+
   SECTION("getOverdriveClkControlCmdId")
   {
     SECTION("Returns 's' command id for SCLK control")
@@ -631,6 +705,100 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
     }
   }
 
+  SECTION("getOverdriveClkOffsetControlCmdId")
+  {
+    SECTION("Returns 's' command id for SCLK_OFFSET control")
+    {
+      auto cmdId = ::Utils::AMD::getOverdriveClkOffsetControlCmdId("SCLK");
+      REQUIRE(cmdId == "s");
+    }
+  }
+
+  SECTION("parseOverdriveClkOffsetControls")
+  {
+    SECTION("Returns available CLK_OFFSET controls")
+    {
+      // clang-format off
+      std::vector<std::string> input{"OD_SCLK_OFFSET:",
+                                     "..."};
+      // clang-format on
+
+      auto values = ::Utils::AMD::parseOverdriveClkOffsetControls(input);
+      REQUIRE(values.has_value());
+      REQUIRE(values->size() == 1);
+
+      REQUIRE(values->at(0) == "SCLK");
+    }
+
+    SECTION("Returns nothing when there is no available CLK controls")
+    {
+      std::vector<std::string> input{"OTHER_DATA"};
+
+      auto empty = ::Utils::AMD::parseOverdriveClkOffsetControls(input);
+      REQUIRE_FALSE(empty.has_value());
+    }
+  }
+
+  SECTION("parseOverdriveClkOffset")
+  {
+    // clang-format off
+    std::vector<std::string> input{"OD_SCLK_OFFSET:",
+                                   "-10MHz"};
+    // clang-format on
+
+    SECTION("Returns the offset control value")
+    {
+      auto value = ::Utils::AMD::parseOverdriveClkOffset("SCLK", input);
+      REQUIRE(value.has_value());
+      REQUIRE(*value == units::frequency::megahertz_t(-10));
+    }
+
+    SECTION("Returns nothing when there is no OD_controlName_OFFSET in input")
+    {
+      // clang-format off
+      std::vector<std::string> input{"OTHER:",
+                                     "300MHz",
+                                     "OD_MCLK:"};
+      // clang-format on
+
+      auto empty = ::Utils::AMD::parseOverdriveClkOffset("SCLK", input);
+      REQUIRE_FALSE(empty.has_value());
+    }
+  }
+
+  SECTION("parseOverdriveClkOffsetRange")
+  {
+    // clang-format off
+    std::vector<std::string> input{"OD_RANGE:",
+                                   "SCLK_OFFSET:     -500MHz       1000MHz"};
+    // clang-format on
+
+    SECTION("Returns minimum and maximum SCLK frequency offset")
+    {
+      auto values = ::Utils::AMD::parseOverdriveClkOffsetRange("SCLK", input);
+      REQUIRE(values.has_value());
+      REQUIRE(values->first == units::frequency::megahertz_t(-500));
+      REQUIRE(values->second == units::frequency::megahertz_t(1000));
+    }
+
+    SECTION("Returns nothing when there is no OD_RANGE in input")
+    {
+      // clang-format off
+      std::vector<std::string> input{"OTHER:",
+                                     "SCLK_OFFSET:     300MHz       2000MHz"};
+      // clang-format on
+
+      auto empty = ::Utils::AMD::parseOverdriveClkOffsetRange("SLCK", input);
+      REQUIRE_FALSE(empty.has_value());
+    }
+
+    SECTION("Returns nothing for unknown controls names")
+    {
+      auto empty = ::Utils::AMD::parseOverdriveClkOffsetRange("OTHER", input);
+      REQUIRE_FALSE(empty.has_value());
+    }
+  }
+
   SECTION("ppOdClkVoltageHasKnownFreqVoltQuirks")
   {
     SECTION("Pre-Vega20 missing range section")
@@ -909,6 +1077,134 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
     }
   }
 
+  SECTION("parseOverdriveFanStop")
+  {
+    // clang-format off
+    std::vector<std::string> input{
+      "FAN_ZERO_RPM_ENABLE:",
+      "1",
+      "OD_RANGE:",
+      "ZERO_RPM_ENABLE: 0 1"
+    };
+    // clang-format on
+
+    SECTION("Returns fan stop state")
+    {
+      auto value = ::Utils::AMD::parseOverdriveFanStop(input);
+      REQUIRE(value.has_value());
+      REQUIRE(*value);
+    }
+
+    SECTION("Returns nothing when there is no FAN_ZERO_RPM_ENABLE: in input")
+    {
+      // clang-format off
+      std::vector<std::string> invalidInput{
+        "OTHER:",
+        "1",
+        "OD_RANGE:",
+        "ZERO_RPM_ENABLE: 0 1"
+      };
+      // clang-format on
+      auto value = ::Utils::AMD::parseOverdriveFanStop(invalidInput);
+      REQUIRE_FALSE(value.has_value());
+    }
+  }
+
+  SECTION("parseOverdriveFanStopTemp")
+  {
+    // clang-format off
+    std::vector<std::string> input{
+      "FAN_ZERO_RPM_STOP_TEMPERATURE:",
+      "20",
+      "OD_RANGE:",
+      "ZERO_RPM_STOP_TEMPERATURE: 10 100"
+    };
+    // clang-format on
+
+    SECTION("Returns fan stop temperature")
+    {
+      auto value = ::Utils::AMD::parseOverdriveFanStopTemp(input);
+      REQUIRE(value.has_value());
+      REQUIRE(*value == units::temperature::celsius_t(20));
+    }
+
+    SECTION("Returns nothing when there is no FAN_ZERO_RPM_STOP_TEMPERATURE: "
+            "in input")
+    {
+      // clang-format off
+      std::vector<std::string> invalidInput{
+        "OTHER:",
+        "20",
+        "OD_RANGE:",
+        "ZERO_RPM_STOP_TEMPERATURE: 10 100"
+      };
+      // clang-format on
+      auto value = ::Utils::AMD::parseOverdriveFanStopTemp(invalidInput);
+      REQUIRE_FALSE(value.has_value());
+    }
+  }
+
+  SECTION("parseOverdriveFanStopTempRange")
+  {
+    // clang-format off
+    std::vector<std::string> input{
+      "FAN_ZERO_RPM_STOP_TEMPERATURE:",
+      "20",
+      "OD_RANGE:",
+      "ZERO_RPM_STOP_TEMPERATURE: 10 100"
+    };
+    // clang-format on
+
+    SECTION("Returns minimum and maximum fan stop temperature")
+    {
+      auto value = ::Utils::AMD::parseOverdriveFanStopTempRange(input);
+      REQUIRE(value.has_value());
+      REQUIRE(value->first == units::temperature::celsius_t(10));
+      REQUIRE(value->second == units::temperature::celsius_t(100));
+    }
+
+    SECTION("Returns nothing when there is no OD_RANGE: in input")
+    {
+      // clang-format off
+      std::vector<std::string> invalidInput{
+        "FAN_ZERO_RPM_STOP_TEMPERATURE:",
+        "20",
+        "OTHER:",
+        "ZERO_RPM_STOP_TEMPERATURE: 10 100"
+      };
+      // clang-format on
+      auto value = ::Utils::AMD::parseOverdriveFanStopTempRange(invalidInput);
+      REQUIRE_FALSE(value.has_value());
+    }
+  }
+
+  SECTION("isPowerProfileModeDataColumnar")
+  {
+    SECTION("Returns true when power profile mode data has columnar format")
+    {
+      // clang-format off
+      std::vector<std::string> data{"     0 BOOTUP_DEFAULT* 1  3D_FULL_SCREEN  2   POWER_SAVING   3 VIDEO"};
+      // clang-format on
+
+      REQUIRE(::Utils::AMD::isPowerProfileModeDataColumnar(data));
+    }
+
+    SECTION("Returns false when power profile mode data does not have columnar "
+            "format")
+    {
+      // clang-format off
+      std::vector<std::string> data{"NUM  MODE_NAME   SCLK_UP_HYST   SCLK_DOWN_HYST SCLK_ACTIVE_LEVEL"};
+      // clang-format on
+
+      REQUIRE_FALSE(::Utils::AMD::isPowerProfileModeDataColumnar(data));
+    }
+
+    SECTION("Returns false when power profile mode data is empty")
+    {
+      REQUIRE_FALSE(::Utils::AMD::isPowerProfileModeDataColumnar({}));
+    }
+  }
+
   SECTION("hasOverdriveClkVoltControl")
   {
     SECTION("Returns true when overdrive has clock + voltage state controls")
@@ -961,6 +1257,39 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
     }
   }
 
+  SECTION("hasOverdriveClkOffsetControl")
+  {
+    SECTION("Returns true when overdrive has clock offset controls")
+    {
+      // clang-format off
+      std::vector<std::string> negativeOffsetData{"OD_SCLK_OFFSET:",
+                                                  "-300Mhz"};
+      std::vector<std::string> zeroOffsetData{"OD_SCLK_OFFSET:",
+                                              "0Mhz"};
+      std::vector<std::string> positiveOffsetData{"OD_SCLK_OFFSET:",
+                                                  "1000Mhz"};
+      // clang-format on
+
+      REQUIRE(::Utils::AMD::hasOverdriveClkOffsetControl(negativeOffsetData));
+      REQUIRE(::Utils::AMD::hasOverdriveClkOffsetControl(zeroOffsetData));
+      REQUIRE(::Utils::AMD::hasOverdriveClkOffsetControl(positiveOffsetData));
+    }
+
+    SECTION("Returns false when overdrive has no clock offset controls")
+    {
+      // clang-format off
+      std::vector<std::string> otherClkOffsetControlData{"OD_SCLK:",
+                                                         "0: 300MHz 800mV"};
+      std::vector<std::string> noClkOffsetControlData{"OTHER_DATA"};
+      // clang-format on
+
+      REQUIRE_FALSE(
+          ::Utils::AMD::hasOverdriveClkOffsetControl(otherClkOffsetControlData));
+      REQUIRE_FALSE(
+          ::Utils::AMD::hasOverdriveClkOffsetControl(noClkOffsetControlData));
+    }
+  }
+
   SECTION("hasOverdriveVoltCurveControl")
   {
     SECTION("Returns true when overdrive has voltage curve control")
@@ -1086,23 +1415,6 @@ TEST_CASE("AMD utils tests", "[Utils][AMD]")
       REQUIRE_FALSE(::Utils::AMD::hasOverdriveFanAcousticLimitControl(data));
     }
   }
-
-  SECTION("hasOverdriveFanCurveControl")
-  {
-    SECTION("Returns true when overdrive has fan curve control")
-    {
-      std::vector<std::string> data{"OD_FAN_CURVE:"};
-
-      REQUIRE(::Utils::AMD::hasOverdriveFanCurveControl(data));
-    }
-
-    SECTION("Returns false when overdrive has no fan curve control")
-    {
-      std::vector<std::string> data{"OTHER_DATA"};
-
-      REQUIRE_FALSE(::Utils::AMD::hasOverdriveFanCurveControl(data));
-    }
-  }
 }
 
 } // namespace Tests::Utils::AMD
