@@ -1,14 +1,12 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/components/commonutils.h"
 #include <units.h>
 
-namespace Tests {
-namespace Utils {
-namespace Common {
+namespace Tests::Utils::Common {
 
 TEST_CASE("CommonUtils tests", "[Utils][Common]")
 {
@@ -75,6 +73,5 @@ TEST_CASE("CommonUtils tests", "[Utils][Common]")
     }
   }
 }
-} // namespace Common
-} // namespace Utils
-} // namespace Tests
+
+} // namespace Tests::Utils::Common
