@@ -1,13 +1,12 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "core/info/gpuinfo.h"
 #include "core/info/ihwidtranslator.h"
 
-namespace Tests {
-namespace GPUInfo {
+namespace Tests::GPUInfo {
 
 class ProviderStub : public IGPUInfo::IProvider
 {
@@ -89,5 +88,5 @@ TEST_CASE("GPUInfo tests", "[Info][GPUInfo]")
     REQUIRE(ts.hasCapability("capability"));
   }
 }
-} // namespace GPUInfo
-} // namespace Tests
+
+} // namespace Tests::GPUInfo
