@@ -1,13 +1,12 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 // Copyright 2021 Juan Palacios <jpalaciosdev@gmail.com>
 
-#include <catch2/catch.hpp>
+#include <catch2/catch_all.hpp>
 
 #include "common/commandqueuestub.h"
 #include "core/components/controls/noop.h"
 
-namespace Tests {
-namespace Noop {
+namespace Tests::Noop {
 
 class NoopTestAdapter : public ::Noop
 {
@@ -68,5 +67,5 @@ TEST_CASE("Noop control tests", "[Noop]")
     REQUIRE(ctlCmds.commands().empty());
   }
 }
-} // namespace Noop
-} // namespace Tests
+
+} // namespace Tests::Noop
